API Cookbook — PBxplore 1.1 documentation

# API Cookbook

This page provides some examples, tutorials as notebooks to help you use the API of `PBxplore`.

Basically, PBxplore is structured around 3 modules:

## PBxplore.structure

This module handles the reading of PDB files and trajectory files. Its 2 major functions chain_from_files() and chain_from_trajectory are direclty exposed at the package level.

Look at the notebook PB assignation for further information.

Note

chain_from_trajectory() requires the installation of python library MDAnalysis

## PBxplore.io

This module is about the I/O of all files other than PDB. It handles the reading/writing of fasta files and the writing of text-like analysis files (Neq files).

Look at the notebook Writing PB in file for further information.

## PBxplore.analysis

This module handle all analysis functions and ploting functions. You can:

- generate map of the distribution of PBs along protein sequence with plot_map().
- compute Neq with compute_neq() and generate the plot with plot_neq().
- generate WebLogo-like representation of PBs frequency along protein sequence with generate_weblogo().

Look at the notebook Visualize protein deformability for further information.

Note

Plotting functions require Matplotlib.

Note

generate_weblogo() requires Weblogo3.

- PB assignation
- Writing PB in file
- Visualize protein deformability